@@ -10,7 +10,7 @@ use warnings;
 #my $VERSION="0.1";
 
 #For CVS , use following line
-our $VERSION=sprintf("%d.%04d", q$Revision: 2006.0606 $ =~ /(\d+)\.(\d+)/);
+our $VERSION=sprintf("%d.%04d", q$Revision: 2006.0609 $ =~ /(\d+)\.(\d+)/);
 
 BEGIN {
 
@@ -2610,11 +2610,11 @@ WWW::YouTube::XML::API - How to Interface with YouTube using HTTP Protocol and X
 
  Options;
 
-   TBD
+   --xml_api_*
 
 =head1 OPTIONS
 
-TBD
+--xml_api_*
 
 =head1 DESCRIPTION
 
@@ -2626,7 +2626,7 @@ I<L<WWW::YouTube>> I<L<WWW::YouTube::ML::API>> I<L<WWW::YouTube::HTML::API>> I<L
 
 =head1 AUTHOR
 
- Copyright (C) 2006 Eric R. Meyers <ermeyers@adelphia.net>
+ Copyright (C) 2006 Eric R. Meyers E<lt>ermeyers@adelphia.netE<gt>
 
 =cut
 
